spawn_transaction_no_commit_send_result

Macro spawn_transaction_no_commit_send_result 

macro_rules! spawn_transaction_no_commit_send_result {
    ($shared_config:ident, bounded, $tx:ident, $fetch_fn:expr) => { ... };
    ($shared_config:ident, unbounded, $tx:ident, $fetch_fn:expr) => { ... };
}
Run a code block that requires a database connection in a context in which one is made available. The transaction is not committed and thus this should only be used in contexts where that is desired (i.e. read-only).